@@ -18,7 +18,7 @@ from .decorator import aioretry, retry, smart_decorator, synchronize, timeit
 from .email_utils import AioEmail, Email
 from .fire import Fire
 from .http_utils import Chrome, Response, patch_connection_pool
-from .ip2region import Ip2Region
+from .xdb_searcher import XdbSearcher
 from .log_utils import Logger, WatchedFileHandler
 from .rabbitmq import AioPika, Pika
 
