@@ -97,12 +97,12 @@ class Response:
                 setattr(self, k, v)
 
         if hasattr(self, 'headers') and isinstance(self.headers, httputil.HTTPHeaders):
-            self.cookies = {}
+            self.cookies = Dict()
             if self.code == 200:
                 sc = SimpleCookie()
                 for cookie in self.headers.get_list('Set-Cookie'):
                     sc.load(cookie)
-                self.cookies = dict(map(lambda x: (x[0], x[1].value), sc.items()))
+                self.cookies = Dict(map(lambda x: (x[0], x[1].value), sc.items()))
             self.headers = CaseInsensitiveDict(self.headers.items())
         elif not hasattr(self, 'headers'):
             self.headers = CaseInsensitiveDict()
@@ -718,7 +718,7 @@ class Fetcher(BaseRequest):
 
 class Chrome(webdriver.Chrome):
 
-    def __init__(self, path=None, headless=False, proxy=None, mobile=False):
+    def __init__(self, path=None, headless=False, proxy=None, mobile=None):
         options = webdriver.ChromeOptions()
         options.add_experimental_option('excludeSwitches', ['enable-automation', 'ignore-certificate-errors'])
         options.add_experimental_option('w3c', False)
