@@ -53,7 +53,7 @@ def Logger(filename=None, name=None, level='INFO', stream=True, prefix=None):
     logger.setLevel(level.upper())
     logger.propagate = False
     logger.handlers = []
-    logfmt = '[%(levelname)1.1s %(asctime)s %(filename)s:%(lineno)d] %(message)s'
+    logfmt = '[%(levelname)1.1s %(asctime)s %(module)s:%(lineno)d] %(message)s'
 
     if stream:
         handler = logging.StreamHandler()
